.. bcolz documentation master file, created by
   sphinx-quickstart on Mon Dec 13 13:54:01 2010.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to bcolz's documentation!
==================================

Contents:

.. toctree::
   :maxdepth: 2

   intro
   install
   tutorial
   reference
   opt-tips
   defaults

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

